import { createSelectorCreator } from 'reselect'
import LRU from 'lru'

const hashFn = (...args) => args.reduce(
  (acc, val) => acc + '-' + JSON.stringify(val),
  ''
)

export default createSelectorCreator(fn => {
  const cache = new LRU(10)

  return function () {
    const argumentHash = hashFn.apply(null, arguments)
    if (cache.get(argumentHash)) {
      return cache.get(argumentHash)
    }

    const val = fn.apply(null, arguments)
    cache.set(argumentHash, val)
    return val
  }
})
